==> ng2-bootstrap-1.0.11.jar: META-INF/resources/webjars/ng2-bootstrap/1.0.11/components/timepicker/readme.md <==
### Usage
```typescript
import { Timepicker } from 'ng2-bootstrap/ng2-bootstrap';
```

### Annotations
```typescript
// component Timepicker
@Component({
  selector: 'timepicker[ngModel]',
  directives: [NgClass]
})
export class Timepicker implements ControlValueAccessor, OnInit {
  // config
  @Input() private hourStep:number;
  @Input() private minuteStep:number;
  @Input() private readonlyInput:boolean;
  @Input() private mousewheel:boolean;
  @Input() private arrowkeys:boolean;
  @Input() private showSpinners:boolean;
  @Input() private min:Date;
  @Input() private max:Date;
  @Input() private meridians:Array<string> = ['AM', 'PM']; // ??

  @Input() private get showMeridian() {}
}
```

### Timepicker properties
  - `vertical` (`?boolean=false`) - if `true` tabs will be placed vertically
  - `justified` (`?boolean=false`) - if `true` tabs fill the container and have a consistent width
  - `type` (`?string='tabs'`) - navigation context class: 'tabs' or 'pills'

  - `ngModel` (`*Date`) - binds to Date object
  - `hourStep` (`?number=1`) - hours change step
  - `minuteStep` (`?number=1`) - minutes change step
  - `meridians` (`?Array<string> = ['AM', 'PM'];`) - meridian labels based on locale (*will be based later*)
  - `showMeridian` (`?boolean=true`) - if `true` works in 12H mode and displays AM/PM. If `false` works in 24H mode and hides AM/PM
  - `readonlyInput` (`?boolean=false`) - if `true` hours and minutes fields will be readonly
  - `mousewheel` (`?boolean=true`) - if `true` scroll inside hours and minutes inputs will change time
  - `arrowkeys` (`?boolean=true`) - if `true` up/down arrowkeys inside hours and minutes inputs will change time
  - `showSpinners` (`?boolean=true`) - if `true` spinner arrows above and below the inputs will be shown
  - `min` (`?Date:undefined`) - minimum time user can select
  - `max` (`?Date:undefined`) - maximum time user can select

==> ng2-bootstrap-1.0.16.jar: META-INF/resources/webjars/ng2-bootstrap/1.0.16/components/timepicker/readme.md <==
### Usage
```typescript
import { TimepickerComponent } from 'ng2-bootstrap/ng2-bootstrap';
// or
import { TimepickerComponent } from 'ng2-bootstrap/components/timepicker';
```

### Annotations
```typescript
// component Timepicker
@Component({
  selector: 'timepicker[ngModel]',
  directives: [NgClass]
})
export class TimepickerComponent implements ControlValueAccessor, OnInit {
  // config
  @Input() private hourStep:number;
  @Input() private minuteStep:number;
  @Input() private readonlyInput:boolean;
  @Input() private mousewheel:boolean;
  @Input() private arrowkeys:boolean;
  @Input() private showSpinners:boolean;
  @Input() private min:Date;
  @Input() private max:Date;
  @Input() private meridians:Array<string> = ['AM', 'PM']; // ??

  @Input() private get showMeridian() {}
}
```

### Timepicker properties
  - `vertical` (`?boolean=false`) - if `true` tabs will be placed vertically
  - `justified` (`?boolean=false`) - if `true` tabs fill the container and have a consistent width
  - `type` (`?string='tabs'`) - navigation context class: 'tabs' or 'pills'

  - `ngModel` (`*Date`) - binds to Date object
  - `hourStep` (`?number=1`) - hours change step
  - `minuteStep` (`?number=1`) - minutes change step
  - `meridians` (`?Array<string> = ['AM', 'PM'];`) - meridian labels based on locale (*will be based later*)
  - `showMeridian` (`?boolean=true`) - if `true` works in 12H mode and displays AM/PM. If `false` works in 24H mode and hides AM/PM
  - `readonlyInput` (`?boolean=false`) - if `true` hours and minutes fields will be readonly
  - `mousewheel` (`?boolean=true`) - if `true` scroll inside hours and minutes inputs will change time
  - `arrowkeys` (`?boolean=true`) - if `true` up/down arrowkeys inside hours and minutes inputs will change time
  - `showSpinners` (`?boolean=true`) - if `true` spinner arrows above and below the inputs will be shown
  - `min` (`?Date:undefined`) - minimum time user can select
  - `max` (`?Date:undefined`) - maximum time user can select
